==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/WebSortingEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebSortingEventArgsDetailDescriptionMetadata } from "./WebSortingEventArgsDetailDescriptionMetadata";
import { WebSortingEventArgsDescription } from "./WebSortingEventArgsDescription";
/**
 * @hidden
 */
var WebSortingEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebSortingEventArgsDescriptionMetadata, _super);
    function WebSortingEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebSortingEventArgsDescriptionMetadata.b = function (a) {
        if (WebSortingEventArgsDescriptionMetadata.a == null) {
            WebSortingEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebSortingEventArgsDescriptionMetadata.c(WebSortingEventArgsDescriptionMetadata.a);
        }
        if (a.j(WebSortingEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.y(WebSortingEventArgsDescriptionMetadata.a);
        WebSortingEventArgsDetailDescriptionMetadata.d(a);
    };
    WebSortingEventArgsDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:SortingEventArgs");
        a.item("__isPlainObject", "Boolean");
        a.item("Detail", "ExportedType:WebSortingEventArgsDetail");
    };
    WebSortingEventArgsDescriptionMetadata.d = function (a) {
        WebSortingEventArgsDescriptionMetadata.b(a);
        a.aa("WebSortingEventArgs", function () { return new WebSortingEventArgsDescription(); });
        a.z("WebSortingEventArgs", WebSortingEventArgsDescriptionMetadata.a);
    };
    WebSortingEventArgsDescriptionMetadata.$t = markType(WebSortingEventArgsDescriptionMetadata, 'WebSortingEventArgsDescriptionMetadata');
    WebSortingEventArgsDescriptionMetadata.a = null;
    return WebSortingEventArgsDescriptionMetadata;
}(Base));
export { WebSortingEventArgsDescriptionMetadata };

==> igniteui-react-core-18.1.3.tgz: package/esm5/lib/WebSortingEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebSortingEventArgsDetailDescriptionMetadata } from "./WebSortingEventArgsDetailDescriptionMetadata";
import { WebSortingEventArgsDescription } from "./WebSortingEventArgsDescription";
/**
 * @hidden
 */
var WebSortingEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebSortingEventArgsDescriptionMetadata, _super);
    function WebSortingEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebSortingEventArgsDescriptionMetadata.b = function (a) {
        if (WebSortingEventArgsDescriptionMetadata.a == null) {
            WebSortingEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebSortingEventArgsDescriptionMetadata.c(WebSortingEventArgsDescriptionMetadata.a);
        }
        if (a.k(WebSortingEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.aa(WebSortingEventArgsDescriptionMetadata.a);
        WebSortingEventArgsDetailDescriptionMetadata.d(a);
    };
    WebSortingEventArgsDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:SortingEventArgs");
        a.item("__isPlainObject", "Boolean");
        a.item("__skipSuffix", "Boolean");
        a.item("Detail", "ExportedType:WebSortingEventArgsDetail");
    };
    WebSortingEventArgsDescriptionMetadata.d = function (a) {
        WebSortingEventArgsDescriptionMetadata.b(a);
        a.ac("WebSortingEventArgs", function () { return new WebSortingEventArgsDescription(); });
        a.ab("WebSortingEventArgs", WebSortingEventArgsDescriptionMetadata.a);
    };
    WebSortingEventArgsDescriptionMetadata.$t = markType(WebSortingEventArgsDescriptionMetadata, 'WebSortingEventArgsDescriptionMetadata');
    WebSortingEventArgsDescriptionMetadata.a = null;
    return WebSortingEventArgsDescriptionMetadata;
}(Base));
export { WebSortingEventArgsDescriptionMetadata };
